# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/transport/internet/tcp/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.xray.common.serial.typed_message_pb import TypedMessage
from typing import Optional
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class Config(ClassMeta):
    header_settings: Optional[TypedMessage] = None
    accept_proxy_protocol: Optional[bool] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n.xcapi/xray/transport/internet/tcp/config.proto\x12\x1bxray.transport.internet.tcp\x1a,xcapi/xray/common/serial/typed_message.proto\"h\n\x06\x43onfig\x12\x39\n\x0fheader_settings\x18\x02 \x01(\x0b\x32 .xray.common.serial.TypedMessage\x12\x1d\n\x15\x61\x63\x63\x65pt_proxy_protocol\x18\x03 \x01(\x08J\x04\x08\x01\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.transport.internet.tcp.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONFIG']._serialized_start = 125
    _globals['_CONFIG']._serialized_end = 229



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/core/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import List, Optional
from dataclasses import dataclass
from xcapi.xray.common.serial.typed_message_pb import TypedMessage
from xcapi.model import ClassMeta


@dataclass
class InboundHandlerConfig(ClassMeta):
    """InboundHandlerConfig is the configuration for inbound handler."""
    tag: Optional[str] = None
    """Tag of the inbound handler. The tag must be unique among all inbound handlers"""
    receiver_settings: Optional[TypedMessage] = None
    """Settings for how this inbound proxy is handled."""
    proxy_settings: Optional[TypedMessage] = None
    """Settings for inbound proxy. Must be one of the inbound proxies."""


@dataclass
class OutboundHandlerConfig(ClassMeta):
    """OutboundHandlerConfig is the configuration for outbound handler."""
    tag: Optional[str] = None
    """Tag of this outbound handler."""
    sender_settings: Optional[TypedMessage] = None
    """Settings for how to dial connection for this outbound handler."""
    proxy_settings: Optional[TypedMessage] = None
    """Settings for this outbound proxy. Must be one of the outbound proxies."""
    expire: Optional[int] = None
    """If not zero, this outbound will be expired in seconds. Not used for now."""
    comment: Optional[str] = None
    """Comment of this outbound handler. Not used for now."""


@dataclass
class Config(ClassMeta):
    """Config is the master config of Xray. Xray takes this config as input and functions accordingly."""
    inbound: Optional[List[InboundHandlerConfig]] = None
    """Inbound handler configurations. Must have at least one item."""
    outbound: Optional[List[OutboundHandlerConfig]] = None
    """Outbound handler configurations. Must have at least one item. The first item is used as default for routing."""
    app: Optional[List[TypedMessage]] = None
    """App is for configurations of all features in Xray. A feature must 
    implement the Feature interface, and its config type must be registered
    through common.RegisterConfig.
    """
    extension: Optional[List[TypedMessage]] = None
    """
    Configuration for extensions. The config may not work if corresponding
    extension is not loaded into Xray. Xray will ignore such config during
    initialization.
    """


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cxcapi/xray/core/config.proto\x12\txray.core\x1a,xcapi/xray/common/serial/typed_message.proto\"\xd8\x01\n\x06\x43onfig\x12\x30\n\x07inbound\x18\x01 \x03(\x0b\x32\x1f.xray.core.InboundHandlerConfig\x12\x32\n\x08outbound\x18\x02 \x03(\x0b\x32 .xray.core.OutboundHandlerConfig\x12-\n\x03\x61pp\x18\x04 \x03(\x0b\x32 .xray.common.serial.TypedMessage\x12\x33\n\textension\x18\x06 \x03(\x0b\x32 .xray.common.serial.TypedMessageJ\x04\x08\x03\x10\x04\"\x9a\x01\n\x14InboundHandlerConfig\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12;\n\x11receiver_settings\x18\x02 \x01(\x0b\x32 .xray.common.serial.TypedMessage\x12\x38\n\x0eproxy_settings\x18\x03 \x01(\x0b\x32 .xray.common.serial.TypedMessage\"\xba\x01\n\x15OutboundHandlerConfig\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x39\n\x0fsender_settings\x18\x02 \x01(\x0b\x32 .xray.common.serial.TypedMessage\x12\x38\n\x0eproxy_settings\x18\x03 \x01(\x0b\x32 .xray.common.serial.TypedMessage\x12\x0e\n\x06\x65xpire\x18\x04 \x01(\x03\x12\x0f\n\x07\x63omment\x18\x05 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.core.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONFIG']._serialized_start = 90
    _globals['_CONFIG']._serialized_end = 306
    _globals['_INBOUNDHANDLERCONFIG']._serialized_start = 309
    _globals['_INBOUNDHANDLERCONFIG']._serialized_end = 463
    _globals['_OUTBOUNDHANDLERCONFIG']._serialized_start = 466
    _globals['_OUTBOUNDHANDLERCONFIG']._serialized_end = 652



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/transport/internet/headers/dns/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class Config(ClassMeta):
    domain: Optional[str] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n6xcapi/xray/transport/internet/headers/dns/config.proto\x12#xray.transport.internet.headers.dns\"\x18\n\x06\x43onfig\x12\x0e\n\x06\x64omain\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.transport.internet.headers.dns.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONFIG']._serialized_start = 95
    _globals['_CONFIG']._serialized_end = 119



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/proxy/blackhole/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.xray.common.serial.typed_message_pb import TypedMessage
from typing import Optional
from dataclasses import dataclass
from xcapi.model import ClassMeta


@dataclass
class NoneResponse(ClassMeta):
    pass


@dataclass
class HTTPResponse(ClassMeta):
    pass


@dataclass
class Config(ClassMeta):
    response: Optional[TypedMessage] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\'xcapi/xray/proxy/blackhole/config.proto\x12\x14xray.proxy.blackhole\x1a,xcapi/xray/common/serial/typed_message.proto\"\x0e\n\x0cNoneResponse\"\x0e\n\x0cHTTPResponse\"<\n\x06\x43onfig\x12\x32\n\x08response\x18\x01 \x01(\x0b\x32 .xray.common.serial.TypedMessageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.proxy.blackhole.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_NONERESPONSE']._serialized_start = 111
    _globals['_NONERESPONSE']._serialized_end = 125
    _globals['_HTTPRESPONSE']._serialized_start = 127
    _globals['_HTTPRESPONSE']._serialized_end = 141
    _globals['_CONFIG']._serialized_start = 143
    _globals['_CONFIG']._serialized_end = 203



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/dns/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.xray.common.net.destination_pb import Endpoint
from xcapi.xray.app.router.config_pb import GeoIP
from xcapi.model import ClassMeta
from typing import Optional, List
from dataclasses import dataclass
from enum import Enum


class DomainMatchingType(Enum):
    Full: int = 0
    Subdomain: int = 1
    Keyword: int = 2
    Regex: int = 3


class QueryStrategy(Enum):
    USE_IP: int = 0
    USE_IP4: int = 1
    USE_IP6: int = 2


@dataclass
class NameServer(ClassMeta):
    address: Optional[Endpoint] = None
    client_ip: Optional[bytes] = None
    skipFallback: Optional[bool] = None

    @dataclass
    class PriorityDomain(ClassMeta):
        type: Optional[DomainMatchingType] = None
        domain: Optional[str] = None

    @dataclass
    class OriginalRule(ClassMeta):
        rule: Optional[str] = None
        size: Optional[int] = None

    prioritized_domain: Optional[List[PriorityDomain]] = None
    geoip: Optional[List[GeoIP]] = None
    original_rules: Optional[List[OriginalRule]] = None
    query_strategy: Optional[QueryStrategy] = None


@dataclass
class Config(ClassMeta):
    name_server: Optional[List[NameServer]] = None
    """
    NameServer list used by this DNS client.
    A special value 'localhost' as a domain address can be set to use DNS on local system.
    """
    client_ip: Optional[bytes] = None
    """Client IP for EDNS client subnet. Must be 4 bytes (IPv4) or 16 bytes (IPv6)."""

    @dataclass
    class HostMapping(ClassMeta):
        type: Optional[DomainMatchingType] = None
        domain: Optional[str] = None
        ip: Optional[List[bytes]] = None
        proxied_domain: Optional[str] = None
        """
        ProxiedDomain indicates the mapped domain has the same IP address on this
        domain. Xray will use this domain for IP queries.
        """

    static_hosts: Optional[List[HostMapping]] = None
    tag: Optional[str] = None
    """Tag is the inbound tag of DNS client."""
    disableCache: Optional[bool] = None
    """DisableCache disables DNS cache"""
    query_strategy: Optional[QueryStrategy] = None
    disableFallback: Optional[bool] = None
    disableFallbackIfMatch: Optional[bool] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1fxcapi/xray/app/dns/config.proto\x12\x0cxray.app.dns\x1a\'xcapi/xray/common/net/destination.proto\x1a\"xcapi/xray/app/router/config.proto\"\xbf\x03\n\nNameServer\x12*\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x19.xray.common.net.Endpoint\x12\x11\n\tclient_ip\x18\x05 \x01(\x0c\x12\x14\n\x0cskipFallback\x18\x06 \x01(\x08\x12\x43\n\x12prioritized_domain\x18\x02 \x03(\x0b\x32\'.xray.app.dns.NameServer.PriorityDomain\x12%\n\x05geoip\x18\x03 \x03(\x0b\x32\x16.xray.app.router.GeoIP\x12=\n\x0eoriginal_rules\x18\x04 \x03(\x0b\x32%.xray.app.dns.NameServer.OriginalRule\x12\x33\n\x0equery_strategy\x18\x07 \x01(\x0e\x32\x1b.xray.app.dns.QueryStrategy\x1aP\n\x0ePriorityDomain\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .xray.app.dns.DomainMatchingType\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x1a*\n\x0cOriginalRule\x12\x0c\n\x04rule\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\r\"\x8c\x03\n\x06\x43onfig\x12-\n\x0bname_server\x18\x05 \x03(\x0b\x32\x18.xray.app.dns.NameServer\x12\x11\n\tclient_ip\x18\x03 \x01(\x0c\x12\x36\n\x0cstatic_hosts\x18\x04 \x03(\x0b\x32 .xray.app.dns.Config.HostMapping\x12\x0b\n\x03tag\x18\x06 \x01(\t\x12\x14\n\x0c\x64isableCache\x18\x08 \x01(\x08\x12\x33\n\x0equery_strategy\x18\t \x01(\x0e\x32\x1b.xray.app.dns.QueryStrategy\x12\x17\n\x0f\x64isableFallback\x18\n \x01(\x08\x12\x1e\n\x16\x64isableFallbackIfMatch\x18\x0b \x01(\x08\x1aq\n\x0bHostMapping\x12.\n\x04type\x18\x01 \x01(\x0e\x32 .xray.app.dns.DomainMatchingType\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\n\n\x02ip\x18\x03 \x03(\x0c\x12\x16\n\x0eproxied_domain\x18\x04 \x01(\tJ\x04\x08\x07\x10\x08*E\n\x12\x44omainMatchingType\x12\x08\n\x04\x46ull\x10\x00\x12\r\n\tSubdomain\x10\x01\x12\x0b\n\x07Keyword\x10\x02\x12\t\n\x05Regex\x10\x03*5\n\rQueryStrategy\x12\n\n\x06USE_IP\x10\x00\x12\x0b\n\x07USE_IP4\x10\x01\x12\x0b\n\x07USE_IP6\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.dns.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_DOMAINMATCHINGTYPE']._serialized_start = 975
    _globals['_DOMAINMATCHINGTYPE']._serialized_end = 1044
    _globals['_QUERYSTRATEGY']._serialized_start = 1046
    _globals['_QUERYSTRATEGY']._serialized_end = 1099
    _globals['_NAMESERVER']._serialized_start = 127
    _globals['_NAMESERVER']._serialized_end = 574
    _globals['_NAMESERVER_PRIORITYDOMAIN']._serialized_start = 450
    _globals['_NAMESERVER_PRIORITYDOMAIN']._serialized_end = 530
    _globals['_NAMESERVER_ORIGINALRULE']._serialized_start = 532
    _globals['_NAMESERVER_ORIGINALRULE']._serialized_end = 574
    _globals['_CONFIG']._serialized_start = 577
    _globals['_CONFIG']._serialized_end = 973
    _globals['_CONFIG_HOSTMAPPING']._serialized_start = 854
    _globals['_CONFIG_HOSTMAPPING']._serialized_end = 967



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/log/command/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class Config(ClassMeta):
    pass


@dataclass
class RestartLoggerRequest(ClassMeta):
    pass


@dataclass
class RestartLoggerResponse(ClassMeta):
    pass


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\'xcapi/xray/app/log/command/config.proto\x12\x14xray.app.log.command\"\x08\n\x06\x43onfig\"\x16\n\x14RestartLoggerRequest\"\x17\n\x15RestartLoggerResponse2{\n\rLoggerService\x12j\n\rRestartLogger\x12*.xray.app.log.command.RestartLoggerRequest\x1a+.xray.app.log.command.RestartLoggerResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.log.command.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONFIG']._serialized_start = 65
    _globals['_CONFIG']._serialized_end = 73
    _globals['_RESTARTLOGGERREQUEST']._serialized_start = 75
    _globals['_RESTARTLOGGERREQUEST']._serialized_end = 97
    _globals['_RESTARTLOGGERRESPONSE']._serialized_start = 99
    _globals['_RESTARTLOGGERRESPONSE']._serialized_end = 122
    _globals['_LOGGERSERVICE']._serialized_start = 124
    _globals['_LOGGERSERVICE']._serialized_end = 247



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/proxy/dns/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.xray.common.net.destination_pb import Endpoint
from typing import Optional, List
from dataclasses import dataclass
from xcapi.model import ClassMeta


@dataclass
class Config(ClassMeta):
    server: Optional[Endpoint] = None
    """Server is the DNS server address. If specified, this address overrides the original one."""
    user_level: Optional[int] = None
    non_IP_query: Optional[str] = None
    block_types: Optional[List[int]] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n!xcapi/xray/proxy/dns/config.proto\x12\x0exray.proxy.dns\x1a\'xcapi/xray/common/net/destination.proto\"r\n\x06\x43onfig\x12)\n\x06server\x18\x01 \x01(\x0b\x32\x19.xray.common.net.Endpoint\x12\x12\n\nuser_level\x18\x02 \x01(\r\x12\x14\n\x0cnon_IP_query\x18\x03 \x01(\t\x12\x13\n\x0b\x62lock_types\x18\x04 \x03(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.proxy.dns.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONFIG']._serialized_start = 94
    _globals['_CONFIG']._serialized_end = 208



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
from xcapi.xray.app.observatory.command import command_pb


class ObservatoryServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetOutboundStatus = channel.unary_unary(
            '/xray.core.app.observatory.command.ObservatoryService/GetOutboundStatus',
            request_serializer=command_pb.GetOutboundStatusRequest.SerializeToString,
            response_deserializer=command_pb.GetOutboundStatusResponse.FromString,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/transport/internet/reality/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, List
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class Config(ClassMeta):
    show: Optional[bool] = None
    dest: Optional[str] = None
    type: Optional[str] = None
    xver: Optional[int] = None
    server_names: Optional[List[str]] = None
    private_key: Optional[bytes] = None
    min_client_ver: Optional[bytes] = None
    max_client_ver: Optional[bytes] = None
    max_time_diff: Optional[int] = None
    short_ids: Optional[List[bytes]] = None
    Fingerprint: Optional[str] = None
    server_name: Optional[str] = None
    public_key: Optional[bytes] = None
    short_id: Optional[bytes] = None
    spider_x: Optional[str] = None
    spider_y: Optional[List[int]] = None
    master_key_log: Optional[str] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n2xcapi/xray/transport/internet/reality/config.proto\x12\x1fxray.transport.internet.reality\"\xd1\x02\n\x06\x43onfig\x12\x0c\n\x04show\x18\x01 \x01(\x08\x12\x0c\n\x04\x64\x65st\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0c\n\x04xver\x18\x04 \x01(\x04\x12\x14\n\x0cserver_names\x18\x05 \x03(\t\x12\x13\n\x0bprivate_key\x18\x06 \x01(\x0c\x12\x16\n\x0emin_client_ver\x18\x07 \x01(\x0c\x12\x16\n\x0emax_client_ver\x18\x08 \x01(\x0c\x12\x15\n\rmax_time_diff\x18\t \x01(\x04\x12\x11\n\tshort_ids\x18\n \x03(\x0c\x12\x13\n\x0b\x46ingerprint\x18\x15 \x01(\t\x12\x13\n\x0bserver_name\x18\x16 \x01(\t\x12\x12\n\npublic_key\x18\x17 \x01(\x0c\x12\x10\n\x08short_id\x18\x18 \x01(\x0c\x12\x10\n\x08spider_x\x18\x19 \x01(\t\x12\x10\n\x08spider_y\x18\x1a \x03(\x03\x12\x16\n\x0emaster_key_log\x18\x1b \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.transport.internet.reality.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONFIG']._serialized_start = 88
    _globals['_CONFIG']._serialized_end = 425



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/proxy/vless/account.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional
from dataclasses import dataclass
from xcapi.model import ClassMeta


@dataclass
class Account(ClassMeta):
    id: Optional[str] = None
    """ID of the account, in the form of a UUID, e.g., "66ad4540-b58c-4ad2-9926-ea63445a9b57"."""
    flow: Optional[str] = None
    """Flow settings. May be "xtls-rprx-vision"."""
    encryption: Optional[str] = None
    """Encryption settings. Only applies to client side, and only accepts "none" for now."""


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n$xcapi/xray/proxy/vless/account.proto\x12\x10xray.proxy.vless\"7\n\x07\x41\x63\x63ount\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04\x66low\x18\x02 \x01(\t\x12\x12\n\nencryption\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.proxy.vless.account_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_ACCOUNT']._serialized_start = 58
    _globals['_ACCOUNT']._serialized_end = 113



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/common/protocol/server_spec.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.model import ClassMeta
from typing import Optional, List
from xcapi.xray.common.net.address_pb import IPOrDomain
from xcapi.xray.common.protocol.user_pb import User
from dataclasses import dataclass


@dataclass
class ServerEndpoint(ClassMeta):
    address: Optional[IPOrDomain] = None
    port: Optional[int] = None
    user: Optional[List[User]] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n,xcapi/xray/common/protocol/server_spec.proto\x12\x14xray.common.protocol\x1a#xcapi/xray/common/net/address.proto\x1a%xcapi/xray/common/protocol/user.proto\"v\n\x0eServerEndpoint\x12,\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1b.xray.common.net.IPOrDomain\x12\x0c\n\x04port\x18\x02 \x01(\r\x12(\n\x04user\x18\x03 \x03(\x0b\x32\x1a.xray.common.protocol.Userb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.common.protocol.server_spec_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SERVERENDPOINT']._serialized_start = 146
    _globals['_SERVERENDPOINT']._serialized_end = 264



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/proxyman/command/command.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.xray.common.protocol.user_pb import User
from xcapi.xray.core.config_pb import InboundHandlerConfig, OutboundHandlerConfig
from xcapi.xray.common.serial.typed_message_pb import TypedMessage
from dataclasses import dataclass
from typing import Optional
from xcapi.model import ClassMeta


@dataclass
class AddUserOperation(ClassMeta):
    user: Optional[User] = None


@dataclass
class RemoveUserOperation(ClassMeta):
    email: Optional[str] = None


@dataclass
class AddInboundRequest(ClassMeta):
    inbound: Optional[InboundHandlerConfig] = None


@dataclass
class AddInboundResponse(ClassMeta):
    pass


@dataclass
class RemoveInboundRequest(ClassMeta):
    tag: Optional[str] = None


@dataclass
class RemoveInboundResponse(ClassMeta):
    pass


@dataclass
class AlterInboundRequest(ClassMeta):
    tag: Optional[str] = None
    operation: Optional[TypedMessage] = None


@dataclass
class AlterInboundResponse(ClassMeta):
    pass


@dataclass
class AddOutboundRequest(ClassMeta):
    outbound: Optional[OutboundHandlerConfig] = None


@dataclass
class AddOutboundResponse(ClassMeta):
    pass


@dataclass
class RemoveOutboundRequest(ClassMeta):
    tag: Optional[str] = None


@dataclass
class RemoveOutboundResponse(ClassMeta):
    pass


@dataclass
class AlterOutboundRequest(ClassMeta):
    tag: Optional[str] = None
    operation: Optional[TypedMessage] = None


@dataclass
class AlterOutboundResponse(ClassMeta):
    pass


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n-xcapi/xray/app/proxyman/command/command.proto\x12\x19xray.app.proxyman.command\x1a%xcapi/xray/common/protocol/user.proto\x1a,xcapi/xray/common/serial/typed_message.proto\x1a\x1cxcapi/xray/core/config.proto\"<\n\x10\x41\x64\x64UserOperation\x12(\n\x04user\x18\x01 \x01(\x0b\x32\x1a.xray.common.protocol.User\"$\n\x13RemoveUserOperation\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"E\n\x11\x41\x64\x64InboundRequest\x12\x30\n\x07inbound\x18\x01 \x01(\x0b\x32\x1f.xray.core.InboundHandlerConfig\"\x14\n\x12\x41\x64\x64InboundResponse\"#\n\x14RemoveInboundRequest\x12\x0b\n\x03tag\x18\x01 \x01(\t\"\x17\n\x15RemoveInboundResponse\"W\n\x13\x41lterInboundRequest\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x33\n\toperation\x18\x02 \x01(\x0b\x32 .xray.common.serial.TypedMessage\"\x16\n\x14\x41lterInboundResponse\"H\n\x12\x41\x64\x64OutboundRequest\x12\x32\n\x08outbound\x18\x01 \x01(\x0b\x32 .xray.core.OutboundHandlerConfig\"\x15\n\x13\x41\x64\x64OutboundResponse\"$\n\x15RemoveOutboundRequest\x12\x0b\n\x03tag\x18\x01 \x01(\t\"\x18\n\x16RemoveOutboundResponse\"X\n\x14\x41lterOutboundRequest\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x33\n\toperation\x18\x02 \x01(\x0b\x32 .xray.common.serial.TypedMessage\"\x17\n\x15\x41lterOutboundResponse\"\x08\n\x06\x43onfig2\xc5\x05\n\x0eHandlerService\x12k\n\nAddInbound\x12,.xray.app.proxyman.command.AddInboundRequest\x1a-.xray.app.proxyman.command.AddInboundResponse\"\x00\x12t\n\rRemoveInbound\x12/.xray.app.proxyman.command.RemoveInboundRequest\x1a\x30.xray.app.proxyman.command.RemoveInboundResponse\"\x00\x12q\n\x0c\x41lterInbound\x12..xray.app.proxyman.command.AlterInboundRequest\x1a/.xray.app.proxyman.command.AlterInboundResponse\"\x00\x12n\n\x0b\x41\x64\x64Outbound\x12-.xray.app.proxyman.command.AddOutboundRequest\x1a..xray.app.proxyman.command.AddOutboundResponse\"\x00\x12w\n\x0eRemoveOutbound\x12\x30.xray.app.proxyman.command.RemoveOutboundRequest\x1a\x31.xray.app.proxyman.command.RemoveOutboundResponse\"\x00\x12t\n\rAlterOutbound\x12/.xray.app.proxyman.command.AlterOutboundRequest\x1a\x30.xray.app.proxyman.command.AlterOutboundResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.proxyman.command.command_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_ADDUSEROPERATION']._serialized_start = 191
    _globals['_ADDUSEROPERATION']._serialized_end = 251
    _globals['_REMOVEUSEROPERATION']._serialized_start = 253
    _globals['_REMOVEUSEROPERATION']._serialized_end = 289
    _globals['_ADDINBOUNDREQUEST']._serialized_start = 291
    _globals['_ADDINBOUNDREQUEST']._serialized_end = 360
    _globals['_ADDINBOUNDRESPONSE']._serialized_start = 362
    _globals['_ADDINBOUNDRESPONSE']._serialized_end = 382
    _globals['_REMOVEINBOUNDREQUEST']._serialized_start = 384
    _globals['_REMOVEINBOUNDREQUEST']._serialized_end = 419
    _globals['_REMOVEINBOUNDRESPONSE']._serialized_start = 421
    _globals['_REMOVEINBOUNDRESPONSE']._serialized_end = 444
    _globals['_ALTERINBOUNDREQUEST']._serialized_start = 446
    _globals['_ALTERINBOUNDREQUEST']._serialized_end = 533
    _globals['_ALTERINBOUNDRESPONSE']._serialized_start = 535
    _globals['_ALTERINBOUNDRESPONSE']._serialized_end = 557
    _globals['_ADDOUTBOUNDREQUEST']._serialized_start = 559
    _globals['_ADDOUTBOUNDREQUEST']._serialized_end = 631
    _globals['_ADDOUTBOUNDRESPONSE']._serialized_start = 633
    _globals['_ADDOUTBOUNDRESPONSE']._serialized_end = 654
    _globals['_REMOVEOUTBOUNDREQUEST']._serialized_start = 656
    _globals['_REMOVEOUTBOUNDREQUEST']._serialized_end = 692
    _globals['_REMOVEOUTBOUNDRESPONSE']._serialized_start = 694
    _globals['_REMOVEOUTBOUNDRESPONSE']._serialized_end = 718
    _globals['_ALTEROUTBOUNDREQUEST']._serialized_start = 720
    _globals['_ALTEROUTBOUNDREQUEST']._serialized_end = 808
    _globals['_ALTEROUTBOUNDRESPONSE']._serialized_start = 810
    _globals['_ALTEROUTBOUNDRESPONSE']._serialized_end = 833
    _globals['_CONFIG']._serialized_start = 835
    _globals['_CONFIG']._serialized_end = 843
    _globals['_HANDLERSERVICE']._serialized_start = 846
    _globals['_HANDLERSERVICE']._serialized_end = 1555



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/metrics/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.model import ClassMeta
from typing import Optional


class Config(ClassMeta):
    """Config is the settings for metrics."""
    tag: Optional[str] = None
    """Tag of the outbound handler that handles metrics http connections."""


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#xcapi/xray/app/metrics/config.proto\x12\x10xray.app.metrics\"\x15\n\x06\x43onfig\x12\x0b\n\x03tag\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.metrics.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONFIG']._serialized_start = 57
    _globals['_CONFIG']._serialized_end = 78



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/transport/internet/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, List
from enum import Enum
from xcapi.xray.common.serial.typed_message_pb import TypedMessage
from xcapi.model import ClassMeta
from dataclasses import dataclass


class DomainStrategy(Enum):
    AS_IS: int = 0
    USE_IP: int = 1
    USE_IP4: int = 2
    USE_IP6: int = 3
    USE_IP46: int = 4
    USE_IP64: int = 5
    FORCE_IP: int = 6
    FORCE_IP4: int = 7
    FORCE_IP6: int = 8
    FORCE_IP46: int = 9
    FORCE_IP64: int = 10


@dataclass
class TransportConfig(ClassMeta):
    protocol_name: Optional[str] = None
    """Type of network that this settings supports."""
    settings: Optional[TypedMessage] = None
    """Specific settings. Must be of the transports."""


@dataclass
class ProxyConfig(ClassMeta):
    tag: Optional[str] = None
    transportLayerProxy: Optional[bool] = None


@dataclass
class CustomSockopt(ClassMeta):
    level: Optional[str] = None
    opt: Optional[str] = None
    value: Optional[str] = None
    type: Optional[str] = None


@dataclass
class SocketConfig(ClassMeta):
    """SocketConfig is options to be applied on network sockets."""
    mark: Optional[int] = None
    """Mark of the connection. If non-zero, the value will be set to SO_MARK."""
    tfo: Optional[int] = None
    """TFO is the state of TFO settings."""

    class TProxyMode(Enum):
        Off: int = 0
        """TProxy is off."""
        TProxy: int = 1
        """TProxy mode."""
        Redirect: int = 2
        """Redirect mode."""

    tproxy: Optional[TProxyMode] = None
    """TProxy is for enabling TProxy socket option."""
    receive_original_dest_address: Optional[bool] = None
    """ReceiveOriginalDestAddress is for enabling IP_RECVORIGDSTADDR socket option. This option is for UDP only."""
    bind_address: Optional[bytes] = None
    bind_port: Optional[int] = None
    accept_proxy_protocol: Optional[bool] = None
    domain_strategy: Optional[DomainStrategy] = None
    dialer_proxy: Optional[str] = None
    tcp_keep_alive_interval: Optional[int] = None
    tcp_keep_alive_idle: Optional[int] = None
    tcp_congestion: Optional[str] = None
    interface: Optional[str] = None
    v6only: Optional[bool] = None
    tcp_window_clamp: Optional[int] = None
    tcp_user_timeout: Optional[int] = None
    tcp_max_seg: Optional[int] = None
    tcp_no_delay: Optional[bool] = None
    tcp_mptcp: Optional[bool] = None
    customSockopt: Optional[List[CustomSockopt]] = None


@dataclass
class StreamConfig(ClassMeta):
    """Effective network."""
    protocol_name: Optional[str] = None
    transport_settings: Optional[List[TransportConfig]] = None
    security_type: Optional[str] = None
    """Type of security. Must be a message name of the settings proto."""
    security_settings: Optional[List[TypedMessage]] = None
    """Settings for transport security. For now the only choice is TLS."""
    socket_settings: Optional[SocketConfig] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n*xcapi/xray/transport/internet/config.proto\x12\x17xray.transport.internet\x1a,xcapi/xray/common/serial/typed_message.proto\"\\\n\x0fTransportConfig\x12\x15\n\rprotocol_name\x18\x03 \x01(\t\x12\x32\n\x08settings\x18\x02 \x01(\x0b\x32 .xray.common.serial.TypedMessage\"\xff\x01\n\x0cStreamConfig\x12\x15\n\rprotocol_name\x18\x05 \x01(\t\x12\x44\n\x12transport_settings\x18\x02 \x03(\x0b\x32(.xray.transport.internet.TransportConfig\x12\x15\n\rsecurity_type\x18\x03 \x01(\t\x12;\n\x11security_settings\x18\x04 \x03(\x0b\x32 .xray.common.serial.TypedMessage\x12>\n\x0fsocket_settings\x18\x06 \x01(\x0b\x32%.xray.transport.internet.SocketConfig\"7\n\x0bProxyConfig\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x1b\n\x13transportLayerProxy\x18\x02 \x01(\x08\"H\n\rCustomSockopt\x12\r\n\x05level\x18\x01 \x01(\t\x12\x0b\n\x03opt\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\"\x8d\x05\n\x0cSocketConfig\x12\x0c\n\x04mark\x18\x01 \x01(\x05\x12\x0b\n\x03tfo\x18\x02 \x01(\x05\x12@\n\x06tproxy\x18\x03 \x01(\x0e\x32\x30.xray.transport.internet.SocketConfig.TProxyMode\x12%\n\x1dreceive_original_dest_address\x18\x04 \x01(\x08\x12\x14\n\x0c\x62ind_address\x18\x05 \x01(\x0c\x12\x11\n\tbind_port\x18\x06 \x01(\r\x12\x1d\n\x15\x61\x63\x63\x65pt_proxy_protocol\x18\x07 \x01(\x08\x12@\n\x0f\x64omain_strategy\x18\x08 \x01(\x0e\x32\'.xray.transport.internet.DomainStrategy\x12\x14\n\x0c\x64ialer_proxy\x18\t \x01(\t\x12\x1f\n\x17tcp_keep_alive_interval\x18\n \x01(\x05\x12\x1b\n\x13tcp_keep_alive_idle\x18\x0b \x01(\x05\x12\x16\n\x0etcp_congestion\x18\x0c \x01(\t\x12\x11\n\tinterface\x18\r \x01(\t\x12\x0e\n\x06v6only\x18\x0e \x01(\x08\x12\x18\n\x10tcp_window_clamp\x18\x0f \x01(\x05\x12\x18\n\x10tcp_user_timeout\x18\x10 \x01(\x05\x12\x13\n\x0btcp_max_seg\x18\x11 \x01(\x05\x12\x14\n\x0ctcp_no_delay\x18\x12 \x01(\x08\x12\x11\n\ttcp_mptcp\x18\x13 \x01(\x08\x12=\n\rcustomSockopt\x18\x14 \x03(\x0b\x32&.xray.transport.internet.CustomSockopt\"/\n\nTProxyMode\x12\x07\n\x03Off\x10\x00\x12\n\n\x06TProxy\x10\x01\x12\x0c\n\x08Redirect\x10\x02*\xa9\x01\n\x0e\x44omainStrategy\x12\t\n\x05\x41S_IS\x10\x00\x12\n\n\x06USE_IP\x10\x01\x12\x0b\n\x07USE_IP4\x10\x02\x12\x0b\n\x07USE_IP6\x10\x03\x12\x0c\n\x08USE_IP46\x10\x04\x12\x0c\n\x08USE_IP64\x10\x05\x12\x0c\n\x08\x46ORCE_IP\x10\x06\x12\r\n\tFORCE_IP4\x10\x07\x12\r\n\tFORCE_IP6\x10\x08\x12\x0e\n\nFORCE_IP46\x10\t\x12\x0e\n\nFORCE_IP64\x10\nb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.transport.internet.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_DOMAINSTRATEGY']._serialized_start = 1257
    _globals['_DOMAINSTRATEGY']._serialized_end = 1426
    _globals['_TRANSPORTCONFIG']._serialized_start = 117
    _globals['_TRANSPORTCONFIG']._serialized_end = 209
    _globals['_STREAMCONFIG']._serialized_start = 212
    _globals['_STREAMCONFIG']._serialized_end = 467
    _globals['_PROXYCONFIG']._serialized_start = 469
    _globals['_PROXYCONFIG']._serialized_end = 524
    _globals['_CUSTOMSOCKOPT']._serialized_start = 526
    _globals['_CUSTOMSOCKOPT']._serialized_end = 598
    _globals['_SOCKETCONFIG']._serialized_start = 601
    _globals['_SOCKETCONFIG']._serialized_end = 1254
    _globals['_SOCKETCONFIG_TPROXYMODE']._serialized_start = 1207
    _globals['_SOCKETCONFIG_TPROXYMODE']._serialized_end = 1254



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/transport/internet/httpupgrade/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, Dict
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class Config(ClassMeta):
    host: Optional[str] = None
    path: Optional[str] = None
    header: Optional[Dict[str, str]] = None
    accept_proxy_protocol: Optional[bool] = None
    ed: Optional[int] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n6xcapi/xray/transport/internet/httpupgrade/config.proto\x12#xray.transport.internet.httpupgrade\"\xc7\x01\n\x06\x43onfig\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12G\n\x06header\x18\x03 \x03(\x0b\x32\x37.xray.transport.internet.httpupgrade.Config.HeaderEntry\x12\x1d\n\x15\x61\x63\x63\x65pt_proxy_protocol\x18\x04 \x01(\x08\x12\n\n\x02\x65\x64\x18\x05 \x01(\r\x1a-\n\x0bHeaderEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.transport.internet.httpupgrade.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONFIG_HEADERENTRY']._loaded_options = None
    _globals['_CONFIG_HEADERENTRY']._serialized_options = b'8\001'
    _globals['_CONFIG']._serialized_start = 96
    _globals['_CONFIG']._serialized_end = 295
    _globals['_CONFIG_HEADERENTRY']._serialized_start = 250
    _globals['_CONFIG_HEADERENTRY']._serialized_end = 295



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/proxy/socks/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, Dict, List
from dataclasses import dataclass
from xcapi.model import ClassMeta
from xcapi.xray.common.protocol.server_spec_pb import ServerEndpoint
from enum import Enum
from xcapi.xray.common.net.address_pb import IPOrDomain


@dataclass
class Account(ClassMeta):
    """Account represents a Socks account."""
    username: Optional[str] = None
    password: Optional[str] = None


class AuthType(Enum):
    """AuthType is the authentication type of Socks proxy."""
    NO_AUTH: int = 0
    """NO_AUTH is for anonymous authentication."""
    PASSWORD: int = 1
    """PASSWORD is for username/password authentication."""


@dataclass
class ServerConfig(ClassMeta):
    """ServerConfig is the protobuf config for Socks server."""
    auth_type: Optional[AuthType] = None
    accounts: Optional[Dict[str, str]] = None
    address: Optional[IPOrDomain] = None
    udp_enabled: Optional[bool] = None
    user_level: Optional[int] = None


class ClientConfig(ClassMeta):
    """ClientConfig is the protobuf config for Socks client."""
    server: Optional[List[ServerEndpoint]] = None
    """Sever is a list of Socks server addresses."""


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n#xcapi/xray/proxy/socks/config.proto\x12\x10xray.proxy.socks\x1a#xcapi/xray/common/net/address.proto\x1a,xcapi/xray/common/protocol/server_spec.proto\"-\n\x07\x41\x63\x63ount\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"\x85\x02\n\x0cServerConfig\x12-\n\tauth_type\x18\x01 \x01(\x0e\x32\x1a.xray.proxy.socks.AuthType\x12>\n\x08\x61\x63\x63ounts\x18\x02 \x03(\x0b\x32,.xray.proxy.socks.ServerConfig.AccountsEntry\x12,\n\x07\x61\x64\x64ress\x18\x03 \x01(\x0b\x32\x1b.xray.common.net.IPOrDomain\x12\x13\n\x0budp_enabled\x18\x04 \x01(\x08\x12\x12\n\nuser_level\x18\x06 \x01(\r\x1a/\n\rAccountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"D\n\x0c\x43lientConfig\x12\x34\n\x06server\x18\x01 \x03(\x0b\x32$.xray.common.protocol.ServerEndpoint*%\n\x08\x41uthType\x12\x0b\n\x07NO_AUTH\x10\x00\x12\x0c\n\x08PASSWORD\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.proxy.socks.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SERVERCONFIG_ACCOUNTSENTRY']._loaded_options = None
    _globals['_SERVERCONFIG_ACCOUNTSENTRY']._serialized_options = b'8\001'
    _globals['_AUTHTYPE']._serialized_start = 521
    _globals['_AUTHTYPE']._serialized_end = 558
    _globals['_ACCOUNT']._serialized_start = 140
    _globals['_ACCOUNT']._serialized_end = 185
    _globals['_SERVERCONFIG']._serialized_start = 188
    _globals['_SERVERCONFIG']._serialized_end = 449
    _globals['_SERVERCONFIG_ACCOUNTSENTRY']._serialized_start = 402
    _globals['_SERVERCONFIG_ACCOUNTSENTRY']._serialized_end = 449
    _globals['_CLIENTCONFIG']._serialized_start = 451
    _globals['_CLIENTCONFIG']._serialized_end = 519



class Protocol(object):
    Vless: str = "vless"
    Vmess: str = "vmess"
    Ss: str = "ss"
    Socks: str = "socks"
    Http: str = "http"
    Trojan: str = "trojan"
    Hysteria2: str = "hysteria2"
    Tuic: str = "tuic"
    Wireguard: str = "wireguard"


class Transport(object):
    Ws: str = "websocket"


class SecurityType(object):
    Tls: str = "tls"



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/proxy/shadowsocks_2022/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, List
from dataclasses import dataclass
from xcapi.model import ClassMeta
from xcapi.xray.common.net.network_pb import Network
from xcapi.xray.common.net.address_pb import IPOrDomain


@dataclass
class ServerConfig(ClassMeta):
    method: Optional[str] = None
    key: Optional[str] = None
    email: Optional[str] = None
    level: Optional[int] = None
    network: Optional[List[Network]] = None


@dataclass
class User(ClassMeta):
    key: Optional[str] = None
    email: Optional[str] = None
    level: Optional[int] = None


@dataclass
class MultiUserServerConfig(ClassMeta):
    method: Optional[str] = None
    key: Optional[str] = None
    users: Optional[List[User]] = None
    network: Optional[List[Network]] = None


@dataclass
class RelayDestination(ClassMeta):
    key: Optional[str] = None
    address: Optional[IPOrDomain] = None
    port: Optional[int] = None
    email: Optional[str] = None
    level: Optional[int] = None


@dataclass
class RelayServerConfig(ClassMeta):
    method: Optional[str] = None
    key: Optional[str] = None
    destinations: Optional[List[RelayDestination]] = None
    network: Optional[List[Network]] = None


@dataclass
class ClientConfig(ClassMeta):
    address: Optional[IPOrDomain] = None
    port: Optional[int] = None
    method: Optional[str] = None
    key: Optional[str] = None
    udp_over_tcp: Optional[bool] = None
    udp_over_tcp_version: Optional[int] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n.xcapi/xray/proxy/shadowsocks_2022/config.proto\x12\x1bxray.proxy.shadowsocks_2022\x1a#xcapi/xray/common/net/network.proto\x1a#xcapi/xray/common/net/address.proto\"t\n\x0cServerConfig\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\x05\x12)\n\x07network\x18\x05 \x03(\x0e\x32\x18.xray.common.net.Network\"\x91\x01\n\x15MultiUserServerConfig\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x30\n\x05users\x18\x03 \x03(\x0b\x32!.xray.proxy.shadowsocks_2022.User\x12)\n\x07network\x18\x04 \x03(\x0e\x32\x18.xray.common.net.Network\"y\n\x10RelayDestination\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x1b.xray.common.net.IPOrDomain\x12\x0c\n\x04port\x18\x03 \x01(\r\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\r\n\x05level\x18\x05 \x01(\x05\"\xa0\x01\n\x11RelayServerConfig\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x43\n\x0c\x64\x65stinations\x18\x03 \x03(\x0b\x32-.xray.proxy.shadowsocks_2022.RelayDestination\x12)\n\x07network\x18\x04 \x03(\x0e\x32\x18.xray.common.net.Network\"1\n\x04User\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\x05\"\x9b\x01\n\x0c\x43lientConfig\x12,\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1b.xray.common.net.IPOrDomain\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x0e\n\x06method\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x14\n\x0cudp_over_tcp\x18\x05 \x01(\x08\x12\x1c\n\x14udp_over_tcp_version\x18\x06 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.proxy.shadowsocks_2022.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SERVERCONFIG']._serialized_start = 153
    _globals['_SERVERCONFIG']._serialized_end = 269
    _globals['_MULTIUSERSERVERCONFIG']._serialized_start = 272
    _globals['_MULTIUSERSERVERCONFIG']._serialized_end = 417
    _globals['_RELAYDESTINATION']._serialized_start = 419
    _globals['_RELAYDESTINATION']._serialized_end = 540
    _globals['_RELAYSERVERCONFIG']._serialized_start = 543
    _globals['_RELAYSERVERCONFIG']._serialized_end = 703
    _globals['_USER']._serialized_start = 705
    _globals['_USER']._serialized_end = 754
    _globals['_CLIENTCONFIG']._serialized_start = 757
    _globals['_CLIENTCONFIG']._serialized_end = 912



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/common/net/port.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.model import ClassMeta
from typing import Optional, List
from dataclasses import dataclass


@dataclass
class PortRange(ClassMeta):
    """PortRange represents a range of ports."""
    From: Optional[int] = None
    """The port that this range starts from."""
    To: Optional[int] = None
    """The port that this range ends with (inclusive)."""


@dataclass
class PortList(ClassMeta):
    """PortList is a list of ports."""
    range: Optional[List[PortRange]] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n xcapi/xray/common/net/port.proto\x12\x0fxray.common.net\"%\n\tPortRange\x12\x0c\n\x04\x46rom\x18\x01 \x01(\r\x12\n\n\x02To\x18\x02 \x01(\r\"5\n\x08PortList\x12)\n\x05range\x18\x01 \x03(\x0b\x32\x1a.xray.common.net.PortRangeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.common.net.port_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_PORTRANGE']._serialized_start = 53
    _globals['_PORTRANGE']._serialized_end = 90
    _globals['_PORTLIST']._serialized_start = 92
    _globals['_PORTLIST']._serialized_end = 145



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/common/net/network.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.model import ClassMeta
from typing import Optional, List
from dataclasses import dataclass
from enum import Enum


class Network(Enum):
    Unknown: int = 0
    TCP: int = 2
    UDP: int = 3
    UNIX: int = 4


@dataclass
class NetworkList(ClassMeta):
    """NetworkList is a list of Networks."""
    network: Optional[List[Network]] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n#xcapi/xray/common/net/network.proto\x12\x0fxray.common.net\"8\n\x0bNetworkList\x12)\n\x07network\x18\x01 \x03(\x0e\x32\x18.xray.common.net.Network*2\n\x07Network\x12\x0b\n\x07Unknown\x10\x00\x12\x07\n\x03TCP\x10\x02\x12\x07\n\x03UDP\x10\x03\x12\x08\n\x04UNIX\x10\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.common.net.network_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_NETWORK']._serialized_start = 114
    _globals['_NETWORK']._serialized_end = 164
    _globals['_NETWORKLIST']._serialized_start = 56
    _globals['_NETWORKLIST']._serialized_end = 112



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/dns/fakedns/fakedns.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.model import ClassMeta
from typing import Optional, List
from dataclasses import dataclass


@dataclass
class FakeDnsPool(ClassMeta):
    ip_pool: Optional[str] = None
    """CIDR of IP pool used as fake DNS IP"""
    lruSize: Optional[int] = None
    """Size of Pool for remembering relationship between domain name and IP address"""


@dataclass
class FakeDnsPoolMulti(ClassMeta):
    pools: Optional[List[FakeDnsPool]] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(xcapi/xray/app/dns/fakedns/fakedns.proto\x12\x14xray.app.dns.fakedns\"/\n\x0b\x46\x61keDnsPool\x12\x0f\n\x07ip_pool\x18\x01 \x01(\t\x12\x0f\n\x07lruSize\x18\x02 \x01(\x03\"D\n\x10\x46\x61keDnsPoolMulti\x12\x30\n\x05pools\x18\x01 \x03(\x0b\x32!.xray.app.dns.fakedns.FakeDnsPoolb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.dns.fakedns.fakedns_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_FAKEDNSPOOL']._serialized_start = 66
    _globals['_FAKEDNSPOOL']._serialized_end = 113
    _globals['_FAKEDNSPOOLMULTI']._serialized_start = 115
    _globals['_FAKEDNSPOOLMULTI']._serialized_end = 183



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/reverse/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.model import ClassMeta
from typing import Optional, List
from dataclasses import dataclass
from enum import Enum


@dataclass
class Control(ClassMeta):
    class State(Enum):
        ACTIVE: int = 0
        DRAIN: int = 1

    state: Optional[State] = None
    random: Optional[bytes] = None


@dataclass
class BridgeConfig(ClassMeta):
    tag: Optional[str] = None
    domain: Optional[str] = None


@dataclass
class PortalConfig(ClassMeta):
    tag: Optional[str] = None
    domain: Optional[str] = None


@dataclass
class Config(ClassMeta):
    bridge_config: Optional[List[BridgeConfig]] = None
    portal_config: Optional[List[PortalConfig]] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n#xcapi/xray/app/reverse/config.proto\x12\x10xray.app.reverse\"i\n\x07\x43ontrol\x12.\n\x05state\x18\x01 \x01(\x0e\x32\x1f.xray.app.reverse.Control.State\x12\x0e\n\x06random\x18\x63 \x01(\x0c\"\x1e\n\x05State\x12\n\n\x06\x41\x43TIVE\x10\x00\x12\t\n\x05\x44RAIN\x10\x01\"+\n\x0c\x42ridgeConfig\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\"+\n\x0cPortalConfig\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\"v\n\x06\x43onfig\x12\x35\n\rbridge_config\x18\x01 \x03(\x0b\x32\x1e.xray.app.reverse.BridgeConfig\x12\x35\n\rportal_config\x18\x02 \x03(\x0b\x32\x1e.xray.app.reverse.PortalConfigb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.reverse.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONTROL']._serialized_start = 57
    _globals['_CONTROL']._serialized_end = 162
    _globals['_CONTROL_STATE']._serialized_start = 132
    _globals['_CONTROL_STATE']._serialized_end = 162
    _globals['_BRIDGECONFIG']._serialized_start = 164
    _globals['_BRIDGECONFIG']._serialized_end = 207
    _globals['_PORTALCONFIG']._serialized_start = 209
    _globals['_PORTALCONFIG']._serialized_end = 252
    _globals['_CONFIG']._serialized_start = 254
    _globals['_CONFIG']._serialized_end = 372



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/commander/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.model import ClassMeta
from typing import Optional, List
from dataclasses import dataclass
from xcapi.xray.common.serial.typed_message_pb import TypedMessage


@dataclass
class Config(ClassMeta):
    """Config is the settings for Commander."""
    tag: Optional[str] = None
    """Tag of the outbound handler that handles grpc connections."""
    listen: Optional[str] = None
    """Network address of commander grpc service."""
    service: Optional[List[TypedMessage]] = None
    """Services that supported by this server. All services must implement Service interface"""


class ReflectionConfig(ClassMeta):
    """ReflectionConfig is the placeholder config for ReflectionService."""
    pass


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n%xcapi/xray/app/commander/config.proto\x12\x12xray.app.commander\x1a,xcapi/xray/common/serial/typed_message.proto\"X\n\x06\x43onfig\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x0e\n\x06listen\x18\x03 \x01(\t\x12\x31\n\x07service\x18\x02 \x03(\x0b\x32 .xray.common.serial.TypedMessage\"\x12\n\x10ReflectionConfigb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.commander.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONFIG']._serialized_start = 107
    _globals['_CONFIG']._serialized_end = 195
    _globals['_REFLECTIONCONFIG']._serialized_start = 197
    _globals['_REFLECTIONCONFIG']._serialized_end = 215



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/proxy/vmess/outbound/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.xray.common.protocol.server_spec_pb import ServerEndpoint
from typing import Optional, List
from dataclasses import dataclass
from xcapi.model import ClassMeta


@dataclass
class Config(ClassMeta):
    Receiver: Optional[List[ServerEndpoint]] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n,xcapi/xray/proxy/vmess/outbound/config.proto\x12\x19xray.proxy.vmess.outbound\x1a,xcapi/xray/common/protocol/server_spec.proto\"@\n\x06\x43onfig\x12\x36\n\x08Receiver\x18\x01 \x03(\x0b\x32$.xray.common.protocol.ServerEndpointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.proxy.vmess.outbound.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONFIG']._serialized_start = 121
    _globals['_CONFIG']._serialized_end = 185



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/proxy/vless/encoding/addons.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional
from dataclasses import dataclass
from xcapi.model import ClassMeta


@dataclass
class Addons(ClassMeta):
    Flow: Optional[str] = None
    Seed: Optional[bytes] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n,xcapi/xray/proxy/vless/encoding/addons.proto\x12\x19xray.proxy.vless.encoding\"$\n\x06\x41\x64\x64ons\x12\x0c\n\x04\x46low\x18\x01 \x01(\t\x12\x0c\n\x04Seed\x18\x02 \x01(\x0c\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.proxy.vless.encoding.addons_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_ADDONS']._serialized_start = 75
    _globals['_ADDONS']._serialized_end = 111



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/common/net/address.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.model import ClassMeta
from typing import Optional
from dataclasses import dataclass


@dataclass
class IPOrDomain(ClassMeta):
    """Address of a network host. It may be either an IP address or a domain address."""
    ip: Optional[bytes] = None
    """IP address. Must by either 4 or 16 bytes."""
    domain: Optional[str] = None
    """Domain address."""


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n#xcapi/xray/common/net/address.proto\x12\x0fxray.common.net\"7\n\nIPOrDomain\x12\x0c\n\x02ip\x18\x01 \x01(\x0cH\x00\x12\x10\n\x06\x64omain\x18\x02 \x01(\tH\x00\x42\t\n\x07\x61\x64\x64ressb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.common.net.address_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_IPORDOMAIN']._serialized_start = 56
    _globals['_IPORDOMAIN']._serialized_end = 111



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
from xcapi.xray.app.stats.command import command_pb


class StatsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetStats = channel.unary_unary(
            '/xray.app.stats.command.StatsService/GetStats',
            request_serializer=command_pb.GetStatsRequest.SerializeToString,
            response_deserializer=command_pb.GetStatsResponse.FromString,
            _registered_method=True)
        self.QueryStats = channel.unary_unary(
            '/xray.app.stats.command.StatsService/QueryStats',
            request_serializer=command_pb.QueryStatsRequest.SerializeToString,
            response_deserializer=command_pb.QueryStatsResponse.FromString,
            _registered_method=True)
        self.GetSysStats = channel.unary_unary(
            '/xray.app.stats.command.StatsService/GetSysStats',
            request_serializer=command_pb.SysStatsRequest.SerializeToString,
            response_deserializer=command_pb.SysStatsResponse.FromString,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/transport/internet/splithttp/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, Dict
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class RandRangeConfig(ClassMeta):
    to: Optional[int] = None

    def setFrom(self, value: int) -> 'RandRangeConfig':
        self.__setattr__('from', value)
        return self


@dataclass
class Multiplexing(ClassMeta):
    maxConcurrency: Optional[RandRangeConfig] = None
    maxConnections: Optional[RandRangeConfig] = None
    cMaxReuseTimes: Optional[RandRangeConfig] = None
    cMaxLifetimeMs: Optional[RandRangeConfig] = None


@dataclass
class Config(ClassMeta):
    host: Optional[str] = None
    path: Optional[str] = None
    header: Optional[Dict[str, str]] = None
    scMaxConcurrentPosts: Optional[RandRangeConfig] = None
    scMaxEachPostBytes: Optional[RandRangeConfig] = None
    scMinPostsIntervalMs: Optional[RandRangeConfig] = None
    noSSEHeader: Optional[bool] = None
    xPaddingBytes: Optional[RandRangeConfig] = None
    xmux: Optional[Multiplexing] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n4xcapi/xray/transport/internet/splithttp/config.proto\x12!xray.transport.internet.splithttp\"\xad\x04\n\x06\x43onfig\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x45\n\x06header\x18\x03 \x03(\x0b\x32\x35.xray.transport.internet.splithttp.Config.HeaderEntry\x12P\n\x14scMaxConcurrentPosts\x18\x04 \x01(\x0b\x32\x32.xray.transport.internet.splithttp.RandRangeConfig\x12N\n\x12scMaxEachPostBytes\x18\x05 \x01(\x0b\x32\x32.xray.transport.internet.splithttp.RandRangeConfig\x12P\n\x14scMinPostsIntervalMs\x18\x06 \x01(\x0b\x32\x32.xray.transport.internet.splithttp.RandRangeConfig\x12\x13\n\x0bnoSSEHeader\x18\x07 \x01(\x08\x12I\n\rxPaddingBytes\x18\x08 \x01(\x0b\x32\x32.xray.transport.internet.splithttp.RandRangeConfig\x12=\n\x04xmux\x18\t \x01(\x0b\x32/.xray.transport.internet.splithttp.Multiplexing\x1a-\n\x0bHeaderEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x0fRandRangeConfig\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x05\x12\n\n\x02to\x18\x02 \x01(\x05\"\xbe\x02\n\x0cMultiplexing\x12J\n\x0emaxConcurrency\x18\x01 \x01(\x0b\x32\x32.xray.transport.internet.splithttp.RandRangeConfig\x12J\n\x0emaxConnections\x18\x02 \x01(\x0b\x32\x32.xray.transport.internet.splithttp.RandRangeConfig\x12J\n\x0e\x63MaxReuseTimes\x18\x03 \x01(\x0b\x32\x32.xray.transport.internet.splithttp.RandRangeConfig\x12J\n\x0e\x63MaxLifetimeMs\x18\x04 \x01(\x0b\x32\x32.xray.transport.internet.splithttp.RandRangeConfigb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.transport.internet.splithttp.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONFIG_HEADERENTRY']._loaded_options = None
    _globals['_CONFIG_HEADERENTRY']._serialized_options = b'8\001'
    _globals['_CONFIG']._serialized_start = 92
    _globals['_CONFIG']._serialized_end = 649
    _globals['_CONFIG_HEADERENTRY']._serialized_start = 604
    _globals['_CONFIG_HEADERENTRY']._serialized_end = 649
    _globals['_RANDRANGECONFIG']._serialized_start = 651
    _globals['_RANDRANGECONFIG']._serialized_end = 694
    _globals['_MULTIPLEXING']._serialized_start = 697
    _globals['_MULTIPLEXING']._serialized_end = 1015



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/transport/internet/tls/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, List
from xcapi.model import ClassMeta
from dataclasses import dataclass
from enum import Enum


@dataclass
class Certificate(ClassMeta):
    certificate: Optional[bytes] = None
    """TLS certificate in x509 format."""
    key: Optional[bytes] = None
    """TLS key in x509 format."""

    class Usage(Enum):
        ENCIPHERMENT: int = 0
        AUTHORITY_VERIFY: int = 1
        AUTHORITY_ISSUE: int = 2

    usage: Optional[Usage] = None
    ocsp_stapling: Optional[int] = None
    certificate_path: Optional[str] = None
    """TLS certificate path"""
    key_path: Optional[str] = None
    """TLS Key path"""
    One_time_loading: Optional[bool] = None
    """If true, one-Time Loading"""
    build_chain: Optional[bool] = None


@dataclass
class Config(ClassMeta):
    allow_insecure: Optional[bool] = None
    """Whether or not to allow self-signed certificates."""
    certificate: Optional[List[Certificate]] = None
    """List of certificates to be served on server."""
    server_name: Optional[str] = None
    """Override server name."""
    next_protocol: Optional[List[str]] = None
    """Lists of string as ALPN values."""
    enable_session_resumption: Optional[bool] = None
    """Whether or not to enable session (ticket) resumption."""
    disable_system_root: Optional[bool] = None
    """If true, root certificates on the system will not be loaded for verification"""
    min_version: Optional[str] = None
    """The minimum TLS version."""
    max_version: Optional[str] = None
    """The maximum TLS version."""
    cipher_suites: Optional[str] = None
    """Specify cipher suites, except for TLS 1.3."""
    fingerprint: Optional[str] = None
    """TLS Client Hello fingerprint (uTLS)."""
    reject_unknown_sni: Optional[bool] = None
    pinned_peer_certificate_chain_sha256: Optional[List[bytes]] = None
    """
    A pinned certificate chain sha256 hash.
    If the server's hash does not match this value, the connection will be aborted.
    This value replace allow_insecure.
    """
    pinned_peer_certificate_public_key_sha256: Optional[List[bytes]] = None
    """
    A pinned certificate public key sha256 hash.
    If the server's public key hash does not match this value, the connection will be aborted.
    This value replace allow_insecure.
    """
    master_key_log: Optional[str] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n.xcapi/xray/transport/internet/tls/config.proto\x12\x1bxray.transport.internet.tls\"\xa6\x02\n\x0b\x43\x65rtificate\x12\x13\n\x0b\x63\x65rtificate\x18\x01 \x01(\x0c\x12\x0b\n\x03key\x18\x02 \x01(\x0c\x12=\n\x05usage\x18\x03 \x01(\x0e\x32..xray.transport.internet.tls.Certificate.Usage\x12\x15\n\rocsp_stapling\x18\x04 \x01(\x04\x12\x18\n\x10\x63\x65rtificate_path\x18\x05 \x01(\t\x12\x10\n\x08key_path\x18\x06 \x01(\t\x12\x18\n\x10One_time_loading\x18\x07 \x01(\x08\x12\x13\n\x0b\x62uild_chain\x18\x08 \x01(\x08\"D\n\x05Usage\x12\x10\n\x0c\x45NCIPHERMENT\x10\x00\x12\x14\n\x10\x41UTHORITY_VERIFY\x10\x01\x12\x13\n\x0f\x41UTHORITY_ISSUE\x10\x02\"\xb6\x03\n\x06\x43onfig\x12\x16\n\x0e\x61llow_insecure\x18\x01 \x01(\x08\x12=\n\x0b\x63\x65rtificate\x18\x02 \x03(\x0b\x32(.xray.transport.internet.tls.Certificate\x12\x13\n\x0bserver_name\x18\x03 \x01(\t\x12\x15\n\rnext_protocol\x18\x04 \x03(\t\x12!\n\x19\x65nable_session_resumption\x18\x05 \x01(\x08\x12\x1b\n\x13\x64isable_system_root\x18\x06 \x01(\x08\x12\x13\n\x0bmin_version\x18\x07 \x01(\t\x12\x13\n\x0bmax_version\x18\x08 \x01(\t\x12\x15\n\rcipher_suites\x18\t \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x0b \x01(\t\x12\x1a\n\x12reject_unknown_sni\x18\x0c \x01(\x08\x12,\n$pinned_peer_certificate_chain_sha256\x18\r \x03(\x0c\x12\x31\n)pinned_peer_certificate_public_key_sha256\x18\x0e \x03(\x0c\x12\x16\n\x0emaster_key_log\x18\x0f \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.transport.internet.tls.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CERTIFICATE']._serialized_start = 80
    _globals['_CERTIFICATE']._serialized_end = 374
    _globals['_CERTIFICATE_USAGE']._serialized_start = 306
    _globals['_CERTIFICATE_USAGE']._serialized_end = 374
    _globals['_CONFIG']._serialized_start = 377
    _globals['_CONFIG']._serialized_end = 815



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/transport/internet/grpc/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class Config(ClassMeta):
    authority: Optional[str] = None
    service_name: Optional[str] = None
    multi_mode: Optional[bool] = None
    idle_timeout: Optional[int] = None
    health_check_timeout: Optional[int] = None
    permit_without_stream: Optional[bool] = None
    initial_windows_size: Optional[int] = None
    user_agent: Optional[str] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n/xcapi/xray/transport/internet/grpc/config.proto\x12%xray.transport.internet.grpc.encoding\"\xca\x01\n\x06\x43onfig\x12\x11\n\tauthority\x18\x01 \x01(\t\x12\x14\n\x0cservice_name\x18\x02 \x01(\t\x12\x12\n\nmulti_mode\x18\x03 \x01(\x08\x12\x14\n\x0cidle_timeout\x18\x04 \x01(\x05\x12\x1c\n\x14health_check_timeout\x18\x05 \x01(\x05\x12\x1d\n\x15permit_without_stream\x18\x06 \x01(\x08\x12\x1c\n\x14initial_windows_size\x18\x07 \x01(\x05\x12\x12\n\nuser_agent\x18\x08 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.transport.internet.grpc.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONFIG']._serialized_start = 91
    _globals['_CONFIG']._serialized_end = 293



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/proxy/vmess/inbound/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, List
from dataclasses import dataclass
from xcapi.model import ClassMeta
from xcapi.xray.common.protocol.user_pb import User


@dataclass
class DetourConfig(ClassMeta):
    to: Optional[str] = None


@dataclass
class DefaultConfig(ClassMeta):
    level: Optional[int] = None


@dataclass
class Config(ClassMeta):
    user: Optional[List[User]] = None
    default: Optional[DefaultConfig] = None
    detour: Optional[DetourConfig] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n+xcapi/xray/proxy/vmess/inbound/config.proto\x12\x18xray.proxy.vmess.inbound\x1a%xcapi/xray/common/protocol/user.proto\"\x1a\n\x0c\x44\x65tourConfig\x12\n\n\x02to\x18\x01 \x01(\t\"\x1e\n\rDefaultConfig\x12\r\n\x05level\x18\x02 \x01(\r\"\xa4\x01\n\x06\x43onfig\x12(\n\x04user\x18\x01 \x03(\x0b\x32\x1a.xray.common.protocol.User\x12\x38\n\x07\x64\x65\x66\x61ult\x18\x02 \x01(\x0b\x32\'.xray.proxy.vmess.inbound.DefaultConfig\x12\x36\n\x06\x64\x65tour\x18\x03 \x01(\x0b\x32&.xray.proxy.vmess.inbound.DetourConfigb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.proxy.vmess.inbound.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_DETOURCONFIG']._serialized_start = 112
    _globals['_DETOURCONFIG']._serialized_end = 138
    _globals['_DEFAULTCONFIG']._serialized_start = 140
    _globals['_DEFAULTCONFIG']._serialized_end = 170
    _globals['_CONFIG']._serialized_start = 173
    _globals['_CONFIG']._serialized_end = 337



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
from xcapi.xray.app.router.command import command_pb


class RoutingServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SubscribeRoutingStats = channel.unary_stream(
            '/xray.app.router.command.RoutingService/SubscribeRoutingStats',
            request_serializer=command_pb.SubscribeRoutingStatsRequest.SerializeToString,
            response_deserializer=command_pb.RoutingContext.FromString,
            _registered_method=True)
        self.TestRoute = channel.unary_unary(
            '/xray.app.router.command.RoutingService/TestRoute',
            request_serializer=command_pb.TestRouteRequest.SerializeToString,
            response_deserializer=command_pb.RoutingContext.FromString,
            _registered_method=True)
        self.GetBalancerInfo = channel.unary_unary(
            '/xray.app.router.command.RoutingService/GetBalancerInfo',
            request_serializer=command_pb.GetBalancerInfoRequest.SerializeToString,
            response_deserializer=command_pb.GetBalancerInfoResponse.FromString,
            _registered_method=True)
        self.OverrideBalancerTarget = channel.unary_unary(
            '/xray.app.router.command.RoutingService/OverrideBalancerTarget',
            request_serializer=command_pb.OverrideBalancerTargetRequest.SerializeToString,
            response_deserializer=command_pb.OverrideBalancerTargetResponse.FromString,
            _registered_method=True)
        self.AddRule = channel.unary_unary(
            '/xray.app.router.command.RoutingService/AddRule',
            request_serializer=command_pb.AddRuleRequest.SerializeToString,
            response_deserializer=command_pb.AddRuleResponse.FromString,
            _registered_method=True)
        self.RemoveRule = channel.unary_unary(
            '/xray.app.router.command.RoutingService/RemoveRule',
            request_serializer=command_pb.RemoveRuleRequest.SerializeToString,
            response_deserializer=command_pb.RemoveRuleResponse.FromString,
            _registered_method=True)



import base64
import re
from dataclasses import dataclass
from typing import Optional, List, Dict, Any
from xcapi.xray.app.proxyman.config_pb import SenderConfig
from xcapi.xray.app.proxyman.command.command_pb import AddOutboundRequest
from xcapi.xray.common.serial.typed_message_pb import ToTypedMessage, GetMessageType, TypedMessage
from xcapi.xray.proxy.vless.outbound.config_pb import Config as VlessOutboundConfig
from xcapi.xray.common.protocol.server_spec_pb import ServerEndpoint
from xcapi.xray.common.net.address_pb import IPOrDomain
from xcapi.xray.common.protocol.user_pb import User
from xcapi.xray.proxy.vless.account_pb import Account as VlessAccount
from xcapi.xray.transport.internet.config_pb import StreamConfig, TransportConfig
from xcapi.xray.transport.internet.websocket.config_pb import Config as WebsocketConfig
from xcapi.xray.transport.internet.tls.config_pb import Config as TlsConfig
from urllib.parse import parse_qs
from xcapi.constant import Protocol, Transport, SecurityType
from xcapi.xray.core.config_pb import OutboundHandlerConfig


@dataclass
class KeyValuePair(object):
    Key: str
    Value: str


class ParamKey(object):
    Encryption: str = "encryption"
    Flow: str = "flow"
    Security: str = "security"
    Sni: str = "sni"
    Alpn: str = "alpn"
    Type: str = "type"
    Host: str = "host"
    Path: str = "path"
    Fp: str = "fp"
    AllowInsecure: str = "allowInsecure"

    Id: str = "id"
    Address: str = "address"
    Port: str = "port"
    Remarks: str = "remarks"
    Protocol: str = "protocol"


class Constants(object):
    Host: str = "host"


updateParam: Dict[str, KeyValuePair] = {
    ParamKey.Type: KeyValuePair("ws", "websocket")
}


class XrayN(object):

    @staticmethod
    def Transform(outbound: str) -> List[AddOutboundRequest]:
        requests: List[AddOutboundRequest] = []
        s: Optional[str] = None
        try:
            b = base64.b64decode(outbound)
            s = b.decode()
        except Exception:
            s = outbound
        servers = [part for part in s.split("\r\n") if part]
        for server in servers:
            requests.append(XrayN.GetAddOutboundRequest(server))
        return requests

    @staticmethod
    def FormatDict(dt: Dict[str, List[Any]]) -> Dict[str, Any]:
        data: Dict[str, Any] = {}
        for key in dt:
            if len(dt[key]) == 1:
                data[key] = dt[key][0]
            else:
                data[key] = dt[key]
        for pKey in updateParam:
            if data.get(pKey) and data.get(pKey) == updateParam.get(pKey).Key:
                data[pKey] = updateParam.get(pKey).Value
        return data

    @staticmethod
    def GetAddOutboundRequest(server: str) -> AddOutboundRequest:
        param: Dict[str, Any] = {}
        # Parse
        # todo Other Protocol
        if re.match(f'^{Protocol.Vless}', server):
            r = r'([^:]+)://([^@]+)@([^:]+):(\d+)\?([^#]+)#{0,1}(.+){0,1}'
            match = re.match(r, server)
            if match:
                data = parse_qs(match.group(5)),
                param = XrayN.FormatDict(data[0])
                param[ParamKey.Protocol] = match.group(1)
                param[ParamKey.Id] = match.group(2)
                param[ParamKey.Address] = match.group(3)
                param[ParamKey.Port] = match.group(4)
                param[ParamKey.Remarks] = match.group(6)
        outbound = OutboundHandlerConfig(
            tag=param.get(ParamKey.Remarks),
            proxy_settings=XrayN.GetProxySettings(param),
            sender_settings=ToTypedMessage(
                SenderConfig(
                    stream_settings=StreamConfig(
                        protocol_name=param.get(ParamKey.Type),
                        transport_settings=[
                            TransportConfig(
                                protocol_name=param.get(ParamKey.Type),
                                settings=XrayN.GetTransportConfigSettings(param),
                            )
                        ],
                        security_type=XrayN.GetSecurityType(param),
                        security_settings=[XrayN.GetSecuritySettings(param)]
                    )
                )
            )
        )
        request: AddOutboundRequest = AddOutboundRequest(
            outbound=outbound,
        )
        return request

    @staticmethod
    def GetProxySettings(param: Dict[str, Any]) -> TypedMessage:
        message: Optional[TypedMessage] = None
        # todo Other Protocol
        if Protocol.Vless == param.get(ParamKey.Protocol):
            oc = VlessOutboundConfig(
                vnext=[ServerEndpoint(
                    address=IPOrDomain(domain=param.get(ParamKey.Address)),
                    port=int(param.get(ParamKey.Port)),
                    user=[
                        User(
                            account=XrayN.GetAccount(param),
                        )
                    ]
                )]
            )
            message = ToTypedMessage(oc)
        return message

    @staticmethod
    def GetAccount(param: Dict[str, Any]) -> TypedMessage:
        message: Optional[TypedMessage] = None
        # todo Other Protocol
        if Protocol.Vless == param.get(ParamKey.Protocol):
            account = VlessAccount(
                id=param.get(ParamKey.Id),
                flow=param.get(ParamKey.Flow),
                encryption=param.get(ParamKey.Encryption),
            )
            message = ToTypedMessage(account)
        return message

    @staticmethod
    def GetTransportConfigSettings(param: Dict[str, Any]) -> TypedMessage:
        message: Optional[TypedMessage] = None
        # todo Other Transport
        if Transport.Ws == param.get(ParamKey.Type):
            config = WebsocketConfig(
                path=param.get(ParamKey.Path),
                host=param.get(ParamKey.Host),
                header={Constants.Host: param.get(ParamKey.Host)} if param.get(ParamKey.Host) else None,
            )
            message = ToTypedMessage(config)
        return message

    @staticmethod
    def GetSecurityType(param: Dict[str, Any]) -> str:
        s: Optional[str] = None
        # todo Other SecurityType
        if SecurityType.Tls == param.get(ParamKey.Security):
            s = GetMessageType(TlsConfig)
        return s

    @staticmethod
    def GetSecuritySettings(param: Dict[str, Any]) -> TypedMessage:
        message: Optional[TypedMessage] = None
        # todo Other SecurityType
        if SecurityType.Tls == param.get(ParamKey.Security):
            cg = TlsConfig(
                allow_insecure=param.get(ParamKey.AllowInsecure),
                fingerprint=param.get(ParamKey.Fp),
            )
            message = ToTypedMessage(cg)
        return message



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/transport/internet/headers/http/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, List
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class Header(ClassMeta):
    name: Optional[str] = None
    """"Accept", "Cookie", etc"""
    value: Optional[List[str]] = None
    """Each entry must be valid in one piece. Random entry will be chosen if multiple entries present."""


@dataclass
class Version(ClassMeta):
    """HTTP version. Default value "1.1"."""
    value: Optional[str] = None


@dataclass
class Method(ClassMeta):
    """HTTP method. Default value "GET"."""
    value: Optional[str] = None


@dataclass
class RequestConfig(ClassMeta):
    version: Optional[Version] = None
    """Full HTTP version like "1.1"."""
    method: Optional[Method] = None
    """GET, POST, CONNECT etc"""
    uri: Optional[List[str]] = None
    """URI like "/login.php"""
    header: Optional[List[Header]] = None


@dataclass
class Status(ClassMeta):
    code: Optional[str] = None
    """Status code. Default "200"."""
    reason: Optional[str] = None
    """Statue reason. Default "OK"."""


@dataclass
class ResponseConfig(ClassMeta):
    version: Optional[Version] = None
    status: Optional[Status] = None
    header: Optional[List[Header]] = None


@dataclass
class Config(ClassMeta):
    request: Optional[RequestConfig] = None
    """
    Settings for authenticating requests. If not set, client side will not send
    authentication header, and server side will bypass authentication.
    """
    response: Optional[ResponseConfig] = None
    """
    Settings for authenticating responses. If not set, client side will bypass
    authentication, and server side will not send authentication header.
    """


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n7xcapi/xray/transport/internet/headers/http/config.proto\x12$xray.transport.internet.headers.http\"%\n\x06Header\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x03(\t\"\x18\n\x07Version\x12\r\n\x05value\x18\x01 \x01(\t\"\x17\n\x06Method\x12\r\n\x05value\x18\x01 \x01(\t\"\xd8\x01\n\rRequestConfig\x12>\n\x07version\x18\x01 \x01(\x0b\x32-.xray.transport.internet.headers.http.Version\x12<\n\x06method\x18\x02 \x01(\x0b\x32,.xray.transport.internet.headers.http.Method\x12\x0b\n\x03uri\x18\x03 \x03(\t\x12<\n\x06header\x18\x04 \x03(\x0b\x32,.xray.transport.internet.headers.http.Header\"&\n\x06Status\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\xcc\x01\n\x0eResponseConfig\x12>\n\x07version\x18\x01 \x01(\x0b\x32-.xray.transport.internet.headers.http.Version\x12<\n\x06status\x18\x02 \x01(\x0b\x32,.xray.transport.internet.headers.http.Status\x12<\n\x06header\x18\x03 \x03(\x0b\x32,.xray.transport.internet.headers.http.Header\"\x96\x01\n\x06\x43onfig\x12\x44\n\x07request\x18\x01 \x01(\x0b\x32\x33.xray.transport.internet.headers.http.RequestConfig\x12\x46\n\x08response\x18\x02 \x01(\x0b\x32\x34.xray.transport.internet.headers.http.ResponseConfigb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.transport.internet.headers.http.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_HEADER']._serialized_start = 97
    _globals['_HEADER']._serialized_end = 134
    _globals['_VERSION']._serialized_start = 136
    _globals['_VERSION']._serialized_end = 160
    _globals['_METHOD']._serialized_start = 162
    _globals['_METHOD']._serialized_end = 185
    _globals['_REQUESTCONFIG']._serialized_start = 188
    _globals['_REQUESTCONFIG']._serialized_end = 404
    _globals['_STATUS']._serialized_start = 406
    _globals['_STATUS']._serialized_end = 444
    _globals['_RESPONSECONFIG']._serialized_start = 447
    _globals['_RESPONSECONFIG']._serialized_end = 651
    _globals['_CONFIG']._serialized_start = 654
    _globals['_CONFIG']._serialized_end = 804



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/observatory/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, List
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class HealthPingMeasurementResult(ClassMeta):
    all: Optional[int] = None
    fail: Optional[int] = None
    deviation: Optional[int] = None
    average: Optional[int] = None
    max: Optional[int] = None
    min: Optional[int] = None


@dataclass
class OutboundStatus(ClassMeta):
    alive: Optional[bool] = None
    """Whether this outbound is usable"""
    delay: Optional[int] = None
    """The time for probe request to finish."""
    last_error_reason: Optional[str] = None
    """The last error caused this outbound failed to relay probe request"""
    outbound_tag: Optional[str] = None
    """The outbound tag for this Server"""
    last_seen_time: Optional[int] = None
    """The time this outbound is known to be alive"""
    last_try_time: Optional[int] = None
    """The time this outbound is tried"""
    health_ping: Optional[HealthPingMeasurementResult] = None


@dataclass
class ObservationResult(ClassMeta):
    status: Optional[List[OutboundStatus]] = None


@dataclass
class ProbeResult(ClassMeta):
    alive: Optional[bool] = None
    """Whether this outbound is usable"""
    delay: Optional[int] = None
    """The time for probe request to finish."""
    last_error_reason: Optional[str] = None
    """The error caused this outbound failed to relay probe request"""


@dataclass
class Intensity(ClassMeta):
    probe_interval: Optional[int] = None
    """The time interval for a probe request in ms."""


@dataclass
class Config(ClassMeta):
    subject_selector: Optional[List[str]] = None
    """The selectors for outbound under observation"""
    probe_url: Optional[str] = None
    probe_interval: Optional[int] = None
    enable_concurrency: Optional[bool] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\'xcapi/xray/app/observatory/config.proto\x12\x19xray.core.app.observatory\"N\n\x11ObservationResult\x12\x39\n\x06status\x18\x01 \x03(\x0b\x32).xray.core.app.observatory.OutboundStatus\"v\n\x1bHealthPingMeasurementResult\x12\x0b\n\x03\x61ll\x18\x01 \x01(\x03\x12\x0c\n\x04\x66\x61il\x18\x02 \x01(\x03\x12\x11\n\tdeviation\x18\x03 \x01(\x03\x12\x0f\n\x07\x61verage\x18\x04 \x01(\x03\x12\x0b\n\x03max\x18\x05 \x01(\x03\x12\x0b\n\x03min\x18\x06 \x01(\x03\"\xdb\x01\n\x0eOutboundStatus\x12\r\n\x05\x61live\x18\x01 \x01(\x08\x12\r\n\x05\x64\x65lay\x18\x02 \x01(\x03\x12\x19\n\x11last_error_reason\x18\x03 \x01(\t\x12\x14\n\x0coutbound_tag\x18\x04 \x01(\t\x12\x16\n\x0elast_seen_time\x18\x05 \x01(\x03\x12\x15\n\rlast_try_time\x18\x06 \x01(\x03\x12K\n\x0bhealth_ping\x18\x07 \x01(\x0b\x32\x36.xray.core.app.observatory.HealthPingMeasurementResult\"F\n\x0bProbeResult\x12\r\n\x05\x61live\x18\x01 \x01(\x08\x12\r\n\x05\x64\x65lay\x18\x02 \x01(\x03\x12\x19\n\x11last_error_reason\x18\x03 \x01(\t\"#\n\tIntensity\x12\x16\n\x0eprobe_interval\x18\x01 \x01(\r\"i\n\x06\x43onfig\x12\x18\n\x10subject_selector\x18\x02 \x03(\t\x12\x11\n\tprobe_url\x18\x03 \x01(\t\x12\x16\n\x0eprobe_interval\x18\x04 \x01(\x03\x12\x1a\n\x12\x65nable_concurrency\x18\x05 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.observatory.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_OBSERVATIONRESULT']._serialized_start = 70
    _globals['_OBSERVATIONRESULT']._serialized_end = 148
    _globals['_HEALTHPINGMEASUREMENTRESULT']._serialized_start = 150
    _globals['_HEALTHPINGMEASUREMENTRESULT']._serialized_end = 268
    _globals['_OUTBOUNDSTATUS']._serialized_start = 271
    _globals['_OUTBOUNDSTATUS']._serialized_end = 490
    _globals['_PROBERESULT']._serialized_start = 492
    _globals['_PROBERESULT']._serialized_end = 562
    _globals['_INTENSITY']._serialized_start = 564
    _globals['_INTENSITY']._serialized_end = 599
    _globals['_CONFIG']._serialized_start = 601
    _globals['_CONFIG']._serialized_end = 706



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/proxyman/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.xray.common.net.port_pb import PortList
from xcapi.xray.common.net.address_pb import IPOrDomain
from xcapi.xray.transport.internet.config_pb import StreamConfig, ProxyConfig
from xcapi.xray.common.serial.typed_message_pb import TypedMessage
from xcapi.model import ClassMeta
from typing import Optional, List
from dataclasses import dataclass
from enum import Enum


@dataclass
class InboundConfig(ClassMeta):
    pass


@dataclass
class AllocationStrategy(ClassMeta):
    class Type(Enum):
        Always: int = 0
        """Always allocate all connection handlers."""
        Random: int = 1
        """Randomly allocate specific range of handlers."""
        External: int = 2
        """External. Not supported yet."""

    type: Optional[Type] = None

    @dataclass
    class AllocationStrategyConcurrency(ClassMeta):
        value: Optional[int] = None

    concurrency: Optional[AllocationStrategyConcurrency] = None
    """Number of handlers (ports) running in parallel.Default value is 3 if unset."""

    @dataclass
    class AllocationStrategyRefresh(ClassMeta):
        value: Optional[int] = None

    refresh: Optional[AllocationStrategyRefresh] = None
    """Number of minutes before a handler is regenerated.Default value is 5 if unset."""


@dataclass
class SniffingConfig(ClassMeta):
    enabled: Optional[bool] = None
    """Whether or not to enable content sniffing on an inbound connection."""
    destination_override: Optional[List[str]] = None
    """
    Override target destination if sniff'ed protocol is in the given list.
    Supported values are "http", "tls", "fakedns".
    """
    domains_excluded: Optional[List[str]] = None
    metadata_only: Optional[bool] = None
    """
    Whether should only try to sniff metadata without waiting for client input.
    Can be used to support SMTP like protocol where server send the first message.
    """
    route_only: Optional[bool] = None


@dataclass
class ReceiverConfig(ClassMeta):
    port_list: Optional[PortList] = None
    """PortList specifies the ports which the Receiver should listen on."""
    listen: Optional[IPOrDomain] = None
    """Listen specifies the IP address that the Receiver should listen on."""
    allocation_strategy: Optional[AllocationStrategy] = None
    stream_settings: Optional[StreamConfig] = None
    receive_original_destination: Optional[bool] = None
    sniffing_settings: Optional[SniffingConfig] = None


@dataclass
class InboundHandlerConfig(ClassMeta):
    tag: Optional[str] = None
    receiver_settings: Optional[TypedMessage] = None
    proxy_settings: Optional[TypedMessage] = None


@dataclass
class OutboundConfig(ClassMeta):
    pass


@dataclass
class MultiplexingConfig(ClassMeta):
    enabled: Optional[bool] = None
    """Whether or not Mux is enabled."""
    concurrency: Optional[int] = None
    """Max number of concurrent connections that one Mux connection can handle."""
    xudpConcurrency: Optional[int] = None
    """Transport XUDP in another Mux."""
    xudpProxyUDP443: Optional[str] = None
    """"reject" (default), "allow" or "skip"."""


@dataclass
class SenderConfig(ClassMeta):
    via: Optional[IPOrDomain] = None
    """Send traffic through the given IP. Only IP is allowed."""
    stream_settings: Optional[StreamConfig] = None
    proxy_settings: Optional[ProxyConfig] = None
    multiplex_settings: Optional[MultiplexingConfig] = None
    via_cidr: Optional[str] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n$xcapi/xray/app/proxyman/config.proto\x12\x11xray.app.proxyman\x1a#xcapi/xray/common/net/address.proto\x1a xcapi/xray/common/net/port.proto\x1a*xcapi/xray/transport/internet/config.proto\x1a,xcapi/xray/common/serial/typed_message.proto\"\x0f\n\rInboundConfig\"\x84\x03\n\x12\x41llocationStrategy\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.xray.app.proxyman.AllocationStrategy.Type\x12X\n\x0b\x63oncurrency\x18\x02 \x01(\x0b\x32\x43.xray.app.proxyman.AllocationStrategy.AllocationStrategyConcurrency\x12P\n\x07refresh\x18\x03 \x01(\x0b\x32?.xray.app.proxyman.AllocationStrategy.AllocationStrategyRefresh\x1a.\n\x1d\x41llocationStrategyConcurrency\x12\r\n\x05value\x18\x01 \x01(\r\x1a*\n\x19\x41llocationStrategyRefresh\x12\r\n\x05value\x18\x01 \x01(\r\",\n\x04Type\x12\n\n\x06\x41lways\x10\x00\x12\n\n\x06Random\x10\x01\x12\x0c\n\x08\x45xternal\x10\x02\"\x84\x01\n\x0eSniffingConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x1c\n\x14\x64\x65stination_override\x18\x02 \x03(\t\x12\x18\n\x10\x64omains_excluded\x18\x03 \x03(\t\x12\x15\n\rmetadata_only\x18\x04 \x01(\x08\x12\x12\n\nroute_only\x18\x05 \x01(\x08\"\xd9\x02\n\x0eReceiverConfig\x12,\n\tport_list\x18\x01 \x01(\x0b\x32\x19.xray.common.net.PortList\x12+\n\x06listen\x18\x02 \x01(\x0b\x32\x1b.xray.common.net.IPOrDomain\x12\x42\n\x13\x61llocation_strategy\x18\x03 \x01(\x0b\x32%.xray.app.proxyman.AllocationStrategy\x12>\n\x0fstream_settings\x18\x04 \x01(\x0b\x32%.xray.transport.internet.StreamConfig\x12$\n\x1creceive_original_destination\x18\x05 \x01(\x08\x12<\n\x11sniffing_settings\x18\x07 \x01(\x0b\x32!.xray.app.proxyman.SniffingConfigJ\x04\x08\x06\x10\x07\"\x9a\x01\n\x14InboundHandlerConfig\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12;\n\x11receiver_settings\x18\x02 \x01(\x0b\x32 .xray.common.serial.TypedMessage\x12\x38\n\x0eproxy_settings\x18\x03 \x01(\x0b\x32 .xray.common.serial.TypedMessage\"\x10\n\x0eOutboundConfig\"\x8b\x02\n\x0cSenderConfig\x12(\n\x03via\x18\x01 \x01(\x0b\x32\x1b.xray.common.net.IPOrDomain\x12>\n\x0fstream_settings\x18\x02 \x01(\x0b\x32%.xray.transport.internet.StreamConfig\x12<\n\x0eproxy_settings\x18\x03 \x01(\x0b\x32$.xray.transport.internet.ProxyConfig\x12\x41\n\x12multiplex_settings\x18\x04 \x01(\x0b\x32%.xray.app.proxyman.MultiplexingConfig\x12\x10\n\x08via_cidr\x18\x05 \x01(\t\"l\n\x12MultiplexingConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x13\n\x0b\x63oncurrency\x18\x02 \x01(\x05\x12\x17\n\x0fxudpConcurrency\x18\x03 \x01(\x05\x12\x17\n\x0fxudpProxyUDP443\x18\x04 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.proxyman.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_INBOUNDCONFIG']._serialized_start = 220
    _globals['_INBOUNDCONFIG']._serialized_end = 235
    _globals['_ALLOCATIONSTRATEGY']._serialized_start = 238
    _globals['_ALLOCATIONSTRATEGY']._serialized_end = 626
    _globals['_ALLOCATIONSTRATEGY_ALLOCATIONSTRATEGYCONCURRENCY']._serialized_start = 490
    _globals['_ALLOCATIONSTRATEGY_ALLOCATIONSTRATEGYCONCURRENCY']._serialized_end = 536
    _globals['_ALLOCATIONSTRATEGY_ALLOCATIONSTRATEGYREFRESH']._serialized_start = 538
    _globals['_ALLOCATIONSTRATEGY_ALLOCATIONSTRATEGYREFRESH']._serialized_end = 580
    _globals['_ALLOCATIONSTRATEGY_TYPE']._serialized_start = 582
    _globals['_ALLOCATIONSTRATEGY_TYPE']._serialized_end = 626
    _globals['_SNIFFINGCONFIG']._serialized_start = 629
    _globals['_SNIFFINGCONFIG']._serialized_end = 761
    _globals['_RECEIVERCONFIG']._serialized_start = 764
    _globals['_RECEIVERCONFIG']._serialized_end = 1109
    _globals['_INBOUNDHANDLERCONFIG']._serialized_start = 1112
    _globals['_INBOUNDHANDLERCONFIG']._serialized_end = 1266
    _globals['_OUTBOUNDCONFIG']._serialized_start = 1268
    _globals['_OUTBOUNDCONFIG']._serialized_end = 1284
    _globals['_SENDERCONFIG']._serialized_start = 1287
    _globals['_SENDERCONFIG']._serialized_end = 1554
    _globals['_MULTIPLEXINGCONFIG']._serialized_start = 1556
    _globals['_MULTIPLEXINGCONFIG']._serialized_end = 1664



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/common/serial/typed_message.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, Any
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class TypedMessage(ClassMeta):
    """TypedMessage is a serialized proto message along with its type name."""
    type: Optional[str] = None
    """The name of the message type, retrieved from protobuf API."""
    value: Optional[bytes] = None
    """Serialized proto message."""


def ToTypedMessage(message: Any) -> 'TypedMessage':
    return TypedMessage(
        type=message.DESCRIPTOR.full_name, value=message.SerializeToString()
    )


def GetMessageType(message: Any) -> str:
    return message.DESCRIPTOR.full_name


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n,xcapi/xray/common/serial/typed_message.proto\x12\x12xray.common.serial\"+\n\x0cTypedMessage\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.common.serial.typed_message_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_TYPEDMESSAGE']._serialized_start = 68
    _globals['_TYPEDMESSAGE']._serialized_end = 111



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
from xcapi.xray.transport.internet.grpc.encoding import stream_pb


class GRPCServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Tun = channel.stream_stream(
            '/xray.transport.internet.grpc.encoding.GRPCService/Tun',
            request_serializer=stream_pb.Hunk.SerializeToString,
            response_deserializer=stream_pb.Hunk.FromString,
            _registered_method=True)
        self.TunMulti = channel.stream_stream(
            '/xray.transport.internet.grpc.encoding.GRPCService/TunMulti',
            request_serializer=stream_pb.MultiHunk.SerializeToString,
            response_deserializer=stream_pb.MultiHunk.FromString,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/app/stats/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional
from xcapi.model import ClassMeta
from dataclasses import dataclass


@dataclass
class Config(ClassMeta):
    pass


@dataclass
class ChannelConfig(ClassMeta):
    Blocking: Optional[bool] = None
    SubscriberLimit: Optional[int] = None
    BufferSize: Optional[int] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n!xcapi/xray/app/stats/config.proto\x12\x0exray.app.stats\"\x08\n\x06\x43onfig\"N\n\rChannelConfig\x12\x10\n\x08\x42locking\x18\x01 \x01(\x08\x12\x17\n\x0fSubscriberLimit\x18\x02 \x01(\x05\x12\x12\n\nBufferSize\x18\x03 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.app.stats.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_CONFIG']._serialized_start = 53
    _globals['_CONFIG']._serialized_end = 61
    _globals['_CHANNELCONFIG']._serialized_start = 63
    _globals['_CHANNELCONFIG']._serialized_end = 141



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/common/protocol/headers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.model import ClassMeta
from typing import Optional
from dataclasses import dataclass
from enum import Enum


class SecurityType(Enum):
    UNKNOWN: int = 0
    AUTO: int = 2
    AES128_GCM: int = 3
    CHACHA20_POLY1305: int = 4
    NONE: int = 5
    """deprecated 2023-06"""
    ZERO: int = 6


@dataclass
class SecurityConfig(ClassMeta):
    type: Optional[SecurityType] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n(xcapi/xray/common/protocol/headers.proto\x12\x14xray.common.protocol\"B\n\x0eSecurityConfig\x12\x30\n\x04type\x18\x01 \x01(\x0e\x32\".xray.common.protocol.SecurityType*`\n\x0cSecurityType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x41UTO\x10\x02\x12\x0e\n\nAES128_GCM\x10\x03\x12\x15\n\x11\x43HACHA20_POLY1305\x10\x04\x12\x08\n\x04NONE\x10\x05\x12\x08\n\x04ZERO\x10\x06\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.common.protocol.headers_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SECURITYTYPE']._serialized_start = 134
    _globals['_SECURITYTYPE']._serialized_end = 230
    _globals['_SECURITYCONFIG']._serialized_start = 66
    _globals['_SECURITYCONFIG']._serialized_end = 132



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/proxy/freedom/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from xcapi.xray.common.protocol.server_spec_pb import ServerEndpoint
from typing import Optional, List
from dataclasses import dataclass
from xcapi.model import ClassMeta
from enum import Enum


@dataclass
class DestinationOverride(ClassMeta):
    server: Optional[ServerEndpoint] = None


@dataclass
class Fragment(ClassMeta):
    packets_from: Optional[int] = None
    packets_to: Optional[int] = None
    length_min: Optional[int] = None
    length_max: Optional[int] = None
    interval_min: Optional[int] = None
    interval_max: Optional[int] = None


@dataclass
class Noise(ClassMeta):
    length_min: Optional[int] = None
    length_max: Optional[int] = None
    delay_min: Optional[int] = None
    delay_max: Optional[int] = None
    str_noise: Optional[bytes] = None


@dataclass
class Config(ClassMeta):
    class DomainStrategy(Enum):
        AS_IS: int = 0
        USE_IP: int = 1
        USE_IP4: int = 2
        USE_IP6: int = 3
        USE_IP46: int = 4
        USE_IP64: int = 5
        FORCE_IP: int = 6
        FORCE_IP4: int = 7
        FORCE_IP6: int = 8
        FORCE_IP46: int = 9
        FORCE_IP64: int = 10

    domain_strategy: Optional[DomainStrategy] = None
    destination_override: Optional[DestinationOverride] = None
    user_level: Optional[int] = None
    fragment: Optional[Fragment] = None
    proxy_protocol: Optional[int] = None
    noises: Optional[List[Noise]] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n%xcapi/xray/proxy/freedom/config.proto\x12\x12xray.proxy.freedom\x1a,xcapi/xray/common/protocol/server_spec.proto\"K\n\x13\x44\x65stinationOverride\x12\x34\n\x06server\x18\x01 \x01(\x0b\x32$.xray.common.protocol.ServerEndpoint\"\x88\x01\n\x08\x46ragment\x12\x14\n\x0cpackets_from\x18\x01 \x01(\x04\x12\x12\n\npackets_to\x18\x02 \x01(\x04\x12\x12\n\nlength_min\x18\x03 \x01(\x04\x12\x12\n\nlength_max\x18\x04 \x01(\x04\x12\x14\n\x0cinterval_min\x18\x05 \x01(\x04\x12\x14\n\x0cinterval_max\x18\x06 \x01(\x04\"h\n\x05Noise\x12\x12\n\nlength_min\x18\x01 \x01(\x04\x12\x12\n\nlength_max\x18\x02 \x01(\x04\x12\x11\n\tdelay_min\x18\x03 \x01(\x04\x12\x11\n\tdelay_max\x18\x04 \x01(\x04\x12\x11\n\tstr_noise\x18\x05 \x01(\x0c\"\xc6\x03\n\x06\x43onfig\x12\x42\n\x0f\x64omain_strategy\x18\x01 \x01(\x0e\x32).xray.proxy.freedom.Config.DomainStrategy\x12\x45\n\x14\x64\x65stination_override\x18\x03 \x01(\x0b\x32\'.xray.proxy.freedom.DestinationOverride\x12\x12\n\nuser_level\x18\x04 \x01(\r\x12.\n\x08\x66ragment\x18\x05 \x01(\x0b\x32\x1c.xray.proxy.freedom.Fragment\x12\x16\n\x0eproxy_protocol\x18\x06 \x01(\r\x12)\n\x06noises\x18\x07 \x03(\x0b\x32\x19.xray.proxy.freedom.Noise\"\xa9\x01\n\x0e\x44omainStrategy\x12\t\n\x05\x41S_IS\x10\x00\x12\n\n\x06USE_IP\x10\x01\x12\x0b\n\x07USE_IP4\x10\x02\x12\x0b\n\x07USE_IP6\x10\x03\x12\x0c\n\x08USE_IP46\x10\x04\x12\x0c\n\x08USE_IP64\x10\x05\x12\x0c\n\x08\x46ORCE_IP\x10\x06\x12\r\n\tFORCE_IP4\x10\x07\x12\r\n\tFORCE_IP6\x10\x08\x12\x0e\n\nFORCE_IP46\x10\t\x12\x0e\n\nFORCE_IP64\x10\nb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.proxy.freedom.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_DESTINATIONOVERRIDE']._serialized_start = 107
    _globals['_DESTINATIONOVERRIDE']._serialized_end = 182
    _globals['_FRAGMENT']._serialized_start = 185
    _globals['_FRAGMENT']._serialized_end = 321
    _globals['_NOISE']._serialized_start = 323
    _globals['_NOISE']._serialized_end = 427
    _globals['_CONFIG']._serialized_start = 430
    _globals['_CONFIG']._serialized_end = 884
    _globals['_CONFIG_DOMAINSTRATEGY']._serialized_start = 715
    _globals['_CONFIG_DOMAINSTRATEGY']._serialized_end = 884



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: xcapi/xray/proxy/wireguard/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
from typing import Optional, List
from dataclasses import dataclass
from xcapi.model import ClassMeta
from enum import Enum


@dataclass
class PeerConfig(ClassMeta):
    public_key: Optional[str] = None
    pre_shared_key: Optional[str] = None
    endpoint: Optional[str] = None
    keep_alive: Optional[int] = None
    allowed_ips: Optional[List[str]] = None


@dataclass
class DeviceConfig(ClassMeta):
    class DomainStrategy(Enum):
        FORCE_IP: int = 0
        FORCE_IP4: int = 1
        FORCE_IP6: int = 2
        FORCE_IP46: int = 3
        FORCE_IP64: int = 4

    secret_key: Optional[str] = None
    endpoint: Optional[List[str]] = None
    peers: Optional[List[PeerConfig]] = None
    mtu: Optional[int] = None
    num_workers: Optional[int] = None
    reserved: Optional[bytes] = None
    domain_strategy: Optional[DomainStrategy] = None
    is_client: Optional[bool] = None
    kernel_mode: Optional[bool] = None


_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\'xcapi/xray/proxy/wireguard/config.proto\x12\x14xray.proxy.wireguard\"s\n\nPeerConfig\x12\x12\n\npublic_key\x18\x01 \x01(\t\x12\x16\n\x0epre_shared_key\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x03 \x01(\t\x12\x12\n\nkeep_alive\x18\x04 \x01(\r\x12\x13\n\x0b\x61llowed_ips\x18\x05 \x03(\t\"\xeb\x02\n\x0c\x44\x65viceConfig\x12\x12\n\nsecret_key\x18\x01 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x02 \x03(\t\x12/\n\x05peers\x18\x03 \x03(\x0b\x32 .xray.proxy.wireguard.PeerConfig\x12\x0b\n\x03mtu\x18\x04 \x01(\x05\x12\x13\n\x0bnum_workers\x18\x05 \x01(\x05\x12\x10\n\x08reserved\x18\x06 \x01(\x0c\x12J\n\x0f\x64omain_strategy\x18\x07 \x01(\x0e\x32\x31.xray.proxy.wireguard.DeviceConfig.DomainStrategy\x12\x11\n\tis_client\x18\x08 \x01(\x08\x12\x13\n\x0bkernel_mode\x18\t \x01(\x08\"\\\n\x0e\x44omainStrategy\x12\x0c\n\x08\x46ORCE_IP\x10\x00\x12\r\n\tFORCE_IP4\x10\x01\x12\r\n\tFORCE_IP6\x10\x02\x12\x0e\n\nFORCE_IP46\x10\x03\x12\x0e\n\nFORCE_IP64\x10\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xcapi.xray.proxy.wireguard.config_pb', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_PEERCONFIG']._serialized_start = 65
    _globals['_PEERCONFIG']._serialized_end = 180
    _globals['_DEVICECONFIG']._serialized_start = 183
    _globals['_DEVICECONFIG']._serialized_end = 546
    _globals['_DEVICECONFIG_DOMAINSTRATEGY']._serialized_start = 454
    _globals['_DEVICECONFIG_DOMAINSTRATEGY']._serialized_end = 546
